Learn R Programming

pspline.inference (version 1.0.4)

pspline.outbreak.cases: Calculate cumulative incidence for an outbreak

Description

This is useful as outcome for pspline.estimate.timeseries.

Usage

pspline.outbreak.cases(model, data)

Arguments

model

model returned by gam or gamm, with a single parameter (time)

data

data frame of predictor values at which the model will be evaluated

Value

data frame of predictor values with corresponding cumulative incidence estimates in $cumcases