Learn R Programming

pspline.inference (version 1.0.4)

pspline.outbreak.cumcases.relative: Calculate relative incidence for an outbreak

Description

This is useful as outcome for pspline.estimate.timeseries.

Usage

pspline.outbreak.cumcases.relative(model, data)

Arguments

model

model returned by gam or gamm, with a single parameter (time)

data

data frame of predictor values at which the model will be evaluated

Value

data frame of predictor values with corresponding relative cumulative incidence estimates in $cumcases.relative