This is mainly used internally by pspline.estimate.scalars, but it's
useful if you want to calculate summary statistics of simulation results other than
the ones returned by pspline.estimate.scalars.
pspline.sample.scalars(model, predictors, calc.outcomes, samples = 100)number of simulations to run
time values at which the model will be evaluated during simulation
scalar outcome generator function; see pspline.estimate.scalars for more info
data frame with one row for each simulation; each row has pspline.sample column giving
a unique ID for the simulation, and one column for each scalar outcome returned by outcomes