This is mainly used internally by pspline.estimate.timeseries, but
it's useful if you want to calculate summary statistics of simulation results other
than the ones returned by pspline.estimate.timeseries.
pspline.sample.timeseries(model, predictors, outcome, samples = 100)time series outcome generator function; see pspline.estimate.timeseries for more info
number of simulations to run
time values at which the model will be evaluated during simulation
matrix with one row for each simulation; each row contains the
time series calculated by outcome for the corresponding simulation run