Run a simulation study to validate a scalar estimator
pspline.validate.scalars(
fun.truth,
n.truths,
fun.observations,
n.observations,
fun.model,
fun.outcomes,
n.samples,
level
)function that generates a true state of the system. Takes no arguments, returns data frame of true values for model variables
number of different truths to generate for simulation study
function that generates a set of observations from truth. Takes one argument (truth data frame) and returns data frame of observations
number of sets of observations to generate for each truth in the simulation study
function that returns a model to be used for estimation. Takes one argument (observations data frame) and returns the model
function that calculates the outcomes of interest. Same as outcomes function in pspline.estimate.scalars.
number of samples to use for estimation. See pspline.estimate.scalars.
confidence level to use for estimation. See pspline.estimate.scalars.
list of summary (which is a data frame specifying the fraction of true values that were contained in their estimated confidence interval) and results (which is a data frame specifying the quantile of the true value in the estimated sampled distribution for each simulation)