Calculate quantiles of model outcome variables
# S3 method for outcomes
quantile(data, model, probs, prob.names)data.frame containing predictor variables and outcome variables
associated model (its formula is used to determine which variables in data are predictors and which are outcomes)
probabilities at which quantiles will be calculated (same as for `quantile`)
format strings used to construct names of the new data columns. For example, if probs is 0.05 and
prob.names is %s.lower, then the 5th percentile of each outcome variable var will be returned in var.lower.
data frame of predictors and associated outcome quantiles.