pspline.outbreak.cases: Calculate cumulative incidence for an outbreak
Usage
pspline.outbreak.cases(model, data)
Arguments
model
model returned by gam or gamm, with a single parameter (time)
data
data frame of predictor values at which the model will be evaluated
Value
data frame of predictor values with corresponding cumulative incidence estimates in $cumcases