pspline.outbreak.cumcases.relative: Calculate relative incidence for an outbreak
Usage
pspline.outbreak.cumcases.relative(model, data)
Arguments
model
model returned by gam or gamm, with a single parameter (time)
data
data frame of predictor values at which the model will be evaluated
Value
data frame of predictor values with corresponding relative cumulative incidence estimates in $cumcases.relative